@@ -15,7 +15,7 @@ import pandas as pd
 
 class GSDBS:
     def __init__(self, creadPath):
-        self.version = "0.1.27"
+        self.version = "0.1.28"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -86,6 +86,7 @@ class GSDBS:
         self.CGSResponseCode['-12'] = 'TYPE ERROR'
         self.CGSResponseCode['-13'] = 'Missing DTABLE'
         self.CGSResponseCode['-14'] = 'Missing DTABLE SCHEMA'
+        self.CGSResponseCode['-15'] = 'Missing QUERY'
 
     def setDTableName(self, dTableName, superDTableName="DTABLE"):
         if dTableName is None or superDTableName is None:
@@ -383,8 +384,9 @@ class GSDBS:
             query = gql(statement)
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
-        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql", headers=api_call_headers, timeout=3600),
-                        fetch_schema_from_transport=False)
+        client = Client(transport=AIOHTTPTransport(url=self.credentials['graphqlapiurl'],
+                                                    headers=api_call_headers),
+                                                    fetch_schema_from_transport=False)
 
         try:
             result = await client.execute_async(query)
@@ -402,8 +404,9 @@ class GSDBS:
             query = gql(statement)
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
-        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql", headers=api_call_headers, timeout=3600),
-                        fetch_schema_from_transport=False)
+        client = Client(transport=AIOHTTPTransport(url=self.credentials['graphqlapiurl'],
+                                                   headers=api_call_headers, timeout=3600),
+                                                   fetch_schema_from_transport=False)
 
         try:
             result = client.execute(query)
@@ -509,8 +512,8 @@ class GSDBS:
 
     def getFileFromCloud(self, filename):
         filename = filename.replace("/","$")
-        # storageURL = "https://glass-sphere-ai.de/storage/file/" + filename
-        storageURL = "http://localhost:8085/storage/file/" + filename
+        storageURL = "https://glass-sphere-ai.de/storage/file/" + filename
+        # storageURL = "http://localhost:8085/storage/file/" + filename
         headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
         resp = requests.get(storageURL, headers=headers)
         buf = io.BytesIO(resp.content)
